==> 0.0.1.tar.gz: lib/core/data/models/expert_model.dart <==
import 'package:freezed_annotation/freezed_annotation.dart';

import 'device_model.dart';

part 'expert_model.freezed.dart';
part 'expert_model.g.dart';

@freezed
class ExpertModel with _$ExpertModel {
  factory ExpertModel(
      {int? id,
      String? email,
      @JsonKey(name: 'password_digest') String? passwordDigest,
      String? name,
      String? address,
      String? phone,
      @JsonKey(name: 'verify_code') String? verifyCode,
      int? verified,
      @JsonKey(name: 'token_user') String? tokenUser,
      @JsonKey(name: 'open_id') dynamic openId,
      @JsonKey(name: 'open_type') String? openType,
      @JsonKey(name: 'open_id_token') dynamic openIdToken,
      String? image,
      int? status,
      String? slug,
      @JsonKey(name: 'set_default_address') dynamic setDefaultAddress,
      String? gender,
      DateTime? birthdate,
      @JsonKey(name: 'current_device_id') dynamic currentDeviceId,
      @JsonKey(name: 'current_device_type') dynamic currentDeviceType,
      @JsonKey(name: 'current_device_name') dynamic currentDeviceName,
      @JsonKey(name: 'current_os_version') dynamic currentOsVersion,
      @JsonKey(name: 'current_app_version') dynamic currentAppVersion,
      @JsonKey(name: 'current_device_token') dynamic currentDeviceToken,
      @JsonKey(name: 'created_at') DateTime? createdAt,
      @JsonKey(name: 'updated_at') DateTime? updatedAt,
      @JsonKey(name: 'province_id') int? provinceId,
      @JsonKey(name: 'district_id') int? districtId,
      @JsonKey(name: 'user_type') String? userType,
      @JsonKey(name: 'hash_tags') List<String>? hashTags,
      @JsonKey(name: 'partner_token') dynamic partnerToken,
      @JsonKey(name: 'partner_type') dynamic partnerType,
      @JsonKey(name: 'classable_type') String? classableType,
      @JsonKey(name: 'classable_id') int? classableId,
      @JsonKey(name: 'profile_link') String? profileLink,
      @JsonKey(name: 'deleted_at') dynamic deletedAt,
      @JsonKey(name: 'member_rate') String? memberRate,
      @JsonKey(name: 'last_activity_at') dynamic lastActivityAt,
      @JsonKey(name: 'request_id') dynamic requestId,
      @JsonKey(name: 'province_name') String? provinceName,
      @JsonKey(name: 'district_name') String? districtName,
      dynamic website,
      dynamic facebook,
      @JsonKey(name: 'hidden_phone') int? hiddenPhone,
      @JsonKey(name: 'ward_id') dynamic wardId,
      @JsonKey(name: 'ward_name') dynamic wardName,
      @JsonKey(name: 'hidden_email') int? hiddenEmail,
      @JsonKey(name: 'hide_toolbar') int? hideToolbar,
      @JsonKey(name: 'background_image') dynamic backgroundImage,
      @JsonKey(name: 'auto_play_video') int? autoPlayVideo,
      @JsonKey(name: 'role_type') String? roleType,
      @JsonKey(name: 'last_sign_out_at') dynamic lastSignOutAt,
      @JsonKey(name: 'referral_id') dynamic referralId,
      int? points,
      dynamic acreage,
      @JsonKey(name: 'family_tree') List<dynamic>? familyTree,
      @JsonKey(name: 'login_times') int? loginTimes,
      String? specialize,
      @JsonKey(name: 'last_sign_in_at') DateTime? lastSignInAt,
      dynamic uid,
      @JsonKey(name: 'trust_score') int? trustScore,
      @JsonKey(name: 'cooperative_type') dynamic cooperativeType,
      @JsonKey(name: 'cooperative_id') dynamic cooperativeId,
      @JsonKey(name: 'manager_id') dynamic managerId,
      @JsonKey(name: 'start_working_time') dynamic startWorkingTime,
      @JsonKey(name: 'end_working_time') dynamic endWorkingTime,
      @JsonKey(name: 'available_suport') dynamic availableSuport,
      @JsonKey(name: 'fb_uid') dynamic fbUid,
      @JsonKey(name: 'devices') List<DeviceModel>? devices}) = _ExpertModel;

  factory ExpertModel.fromJson(Map<String, dynamic> json) =>
      _$ExpertModelFromJson(json);
}

==> 0.0.2+4.tar.gz: lib/core/data/models/expert_model.dart <==
import 'package:freezed_annotation/freezed_annotation.dart';

import 'device_model.dart';

part 'expert_model.freezed.dart';
part 'expert_model.g.dart';

@freezed
class ExpertModel with _$ExpertModel {
  factory ExpertModel(
      {int? id,
      String? email,
      @JsonKey(name: 'password_digest') String? passwordDigest,
      String? name,
      String? address,
      String? phone,
      @JsonKey(name: 'verify_code') String? verifyCode,
      int? verified,
      @JsonKey(name: 'token_user') String? tokenUser,
      @JsonKey(name: 'open_id') dynamic openId,
      @JsonKey(name: 'open_type') String? openType,
      @JsonKey(name: 'open_id_token') dynamic openIdToken,
      String? image,
      int? status,
      String? slug,
      @JsonKey(name: 'set_default_address') dynamic setDefaultAddress,
      String? gender,
      DateTime? birthdate,
      @JsonKey(name: 'current_device_id') dynamic currentDeviceId,
      @JsonKey(name: 'current_device_type') dynamic currentDeviceType,
      @JsonKey(name: 'current_device_name') dynamic currentDeviceName,
      @JsonKey(name: 'current_os_version') dynamic currentOsVersion,
      @JsonKey(name: 'current_app_version') dynamic currentAppVersion,
      @JsonKey(name: 'current_device_token') dynamic currentDeviceToken,
      @JsonKey(name: 'created_at') DateTime? createdAt,
      @JsonKey(name: 'updated_at') DateTime? updatedAt,
      @JsonKey(name: 'province_id') int? provinceId,
      @JsonKey(name: 'district_id') int? districtId,
      @JsonKey(name: 'user_type') String? userType,
      @JsonKey(name: 'user_level') String? userLevel,
      @JsonKey(name: 'partner_token') dynamic partnerToken,
      @JsonKey(name: 'partner_type') dynamic partnerType,
      @JsonKey(name: 'classable_type') String? classableType,
      @JsonKey(name: 'classable_id') int? classableId,
      @JsonKey(name: 'profile_link') String? profileLink,
      @JsonKey(name: 'deleted_at') dynamic deletedAt,
      @JsonKey(name: 'member_rate') String? memberRate,
      @JsonKey(name: 'last_activity_at') dynamic lastActivityAt,
      @JsonKey(name: 'request_id') dynamic requestId,
      @JsonKey(name: 'province_name') String? provinceName,
      @JsonKey(name: 'district_name') String? districtName,
      dynamic website,
      dynamic facebook,
      @JsonKey(name: 'hidden_phone') int? hiddenPhone,
      @JsonKey(name: 'ward_id') dynamic wardId,
      @JsonKey(name: 'ward_name') dynamic wardName,
      @JsonKey(name: 'hidden_email') int? hiddenEmail,
      @JsonKey(name: 'hide_toolbar') int? hideToolbar,
      @JsonKey(name: 'background_image') dynamic backgroundImage,
      @JsonKey(name: 'auto_play_video') int? autoPlayVideo,
      @JsonKey(name: 'role_type') String? roleType,
      @JsonKey(name: 'last_sign_out_at') dynamic lastSignOutAt,
      @JsonKey(name: 'referral_id') dynamic referralId,
      int? points,
      dynamic acreage,
      @JsonKey(name: 'family_tree') List<dynamic>? familyTree,
      @JsonKey(name: 'login_times') int? loginTimes,
      String? specialize,
      @JsonKey(name: 'last_sign_in_at') DateTime? lastSignInAt,
      dynamic uid,
      @JsonKey(name: 'trust_score') double? trustScore,
      @JsonKey(name: 'cooperative_type') dynamic cooperativeType,
      @JsonKey(name: 'cooperative_id') dynamic cooperativeId,
      @JsonKey(name: 'manager_id') dynamic managerId,
      @JsonKey(name: 'start_working_time') DateTime? startWorkingTime,
      @JsonKey(name: 'end_working_time') DateTime? endWorkingTime,
      @JsonKey(name: 'available_suport') dynamic availableSuport,
      @JsonKey(name: 'fb_uid') dynamic fbUid,
      @JsonKey(name: 'devices') List<DeviceModel>? devices}) = _ExpertModel;

  factory ExpertModel.fromJson(Map<String, dynamic> json) =>
      _$ExpertModelFromJson(json);
}
